@@ -28,6 +28,8 @@ ozf = ureg.force_pound/16
 lbf = ureg.force_pound
 lbm = ureg.pound
 kip = ureg.kip
+ton = ureg.ton
+tonf = ureg.force_ton
 plf = ureg.plf
 klf = ureg.klf
 psi = ureg.force_pound/ureg.inch**2
@@ -49,12 +51,17 @@ sec = ureg.second
 hr = ureg.hour
 
 # Add some useful metric units
+g = ureg.gram
+kg = ureg.kilogram
 mm = ureg.millimeter
 cm = ureg.centimeter
 m = ureg.meter
 km = ureg.kilometer
 N = ureg.newton
 kN = ureg.kilonewton
+kgf = ureg.force_kilogram
+ton = ureg.metric_ton
+tonnef = ureg.force_metric_ton
 Pa = ureg.pascal
 kPa = ureg.kilopascal
 MPa = ureg.megapascal
@@ -62,7 +69,7 @@ GPa = ureg.gigapascal
 
 unit_list = ['inch', 'feet', 'ft', 'mi', 'ozf', 'lbf', 'lbm', 'kip', 'plf', 'klf', 'psi', 'psf', 
              'ksi', 'ksf', 'pcf', 'kcf', 'lbin', 'lbft', 'kipin', 'kipft', 'kin', 'kft', 'mph',
-             'sec', 'hr', 'deg', 'rad', 'mm', 'cm', 'm', 'km', 'N', 'kN', 'Pa', 'kPa', 'MPa', 'GPa']
+             'sec', 'hr', 'deg', 'rad', 'mm', 'cm', 'm', 'km', 'N', 'kN', 'kgf', 'Pa', 'kPa', 'MPa', 'GPa']
 
 #%%
 @register_cell_magic
@@ -116,6 +123,8 @@ def sync_namespaces(local_ns):
     local_ns['lbm'] = ureg.pound
     local_ns['kip'] = ureg.kip
     local_ns['k']= ureg.kip
+    local_ns['ton'] = ureg.ton
+    local_ns['tonf'] = ureg.force_ton
     local_ns['plf'] = ureg.plf
     local_ns['klf'] = ureg.klf
     local_ns['psi'] = ureg.force_pound/ureg.inch**2
@@ -143,10 +152,14 @@ def sync_namespaces(local_ns):
     local_ns['km'] = ureg.kilometer
     local_ns['N'] = ureg.newton
     local_ns['kN'] = ureg.kilonewton
+    local_ns['g'] = ureg.gram
+    local_ns['kg'] = ureg.kilogram
     local_ns['Pa'] = ureg.pascal
     local_ns['kPa'] = ureg.kilopascal
     local_ns['MPa'] = ureg.megapascal
-    local_ns['GPa'] = ureg.gigapascal    
+    local_ns['GPa'] = ureg.gigapascal
+    local_ns['tonne'] = ureg.metric_ton
+    local_ns['tonnef'] = ureg.force_metric_ton
 
     # Provide the IPython console with access to the `funit` method
     local_ns['funit'] = funit
@@ -154,6 +167,10 @@ def sync_namespaces(local_ns):
 #%%
 def process_line(calc_line, local_ns):
 
+    # Ampersand symbols will mess with latex table formatting unless they have a `\` in front of
+    # them
+    calc_line = calc_line.replace('&', '\&')
+
     # Break up the line into components: `description`, `variable`, `equation`, `value` and `reference`
     if '#' in calc_line:
         description, reference = calc_line.split('#', 1)
@@ -192,8 +209,8 @@ def process_line(calc_line, local_ns):
     variable = variable.replace('^prime', '_prime')
 
     # Make a latex copy of the equation and variable before we switch out square root symbols
-    latex_variable = to_latex(variable)
-    latex_equation = to_latex(equation)
+    latex_variable = python_to_latex(variable)
+    latex_equation = python_to_latex(equation)
 
     # `Pint` prefers exponents to the 1/2 power instead of square roots
     equation = alt_sqrt(equation)
@@ -329,7 +346,14 @@ def process_line(calc_line, local_ns):
     return latex_text
 
 #%%
-def to_latex(text):
+def python_to_latex(text):
+    """Converts python equations to latex equations
+
+    :param text: Python text to be converted to latex.
+    :type text: str
+    :return: Latex text
+    :rtype: str
+    """
     
     # Change spaces we want to keep to the '@' symbol temporarily
     text = text.replace(' if ', '@if@')
@@ -338,6 +362,9 @@ def to_latex(text):
     # Add any prime symbols back in
     text = text.replace('_prime', '^{\\prime}')
 
+    # Switch out Python's exponent symbols for Latex's
+    text = text.replace('**', '^')
+
     # Add brackets to superscripts and subscripts if they are missing
     text = sscript_curly('^', text)
     text = sscript_curly('_', text)
@@ -355,8 +382,7 @@ def to_latex(text):
     text = text.replace(' ', '')
 
     # Define a list of greek symbols
-    greek = (['alpha', 'eta', 'beta', 'gamma', 'delta', 'epsilon', 'zeta', 'theta', 'iota', 'kappa', 'lambda' 'mu', 'nu', 'xi', 'omicron', 'pi', 'rho', 'sigma', 'tau', 'upsilon', 'phi', 'chi', 'omega', 
-              'Alpha', 'Eta', 'Beta', 'Gamma', 'Delta', 'Epsilon', 'Zeta', 'Theta', 'Iota', 'Kappa', 'Lambda' 'Mu', 'Nu', 'Xi', 'Omicron', 'Pi', 'Rho', 'Sigma', 'Tau', 'Upsilon', 'Phi', 'Chi', 'Psi', 'Omega'])
+    greek = (['alpha', 'eta', 'beta', 'gamma', 'delta', 'epsilon', 'zeta', 'theta', 'iota', 'kappa', 'lambda', 'mu', 'nu', 'xi', 'omicron', 'pi', 'rho', 'sigma', 'tau', 'upsilon', 'phi', 'chi', 'omega', 'Alpha', 'Eta', 'Beta', 'Gamma', 'Delta', 'Epsilon', 'Zeta', 'Theta', 'Iota', 'Kappa', 'Lambda', 'Mu', 'Nu', 'Xi', 'Omicron', 'Pi', 'Rho', 'Sigma', 'Tau', 'Upsilon', 'Phi', 'Chi', 'Psi', 'Omega'])
     
     # Clean up any greek symbols
     for symbol in greek:
@@ -371,16 +397,18 @@ def to_latex(text):
     # Take care of any lower case greek psi characters. This is necessary because 'psi' is also a unit
     text = text.replace('grpsi', '\\psi')
 
-    # Switch out Python's exponent symbols for Latex's
-    text = text.replace('**', '^')
+    #
 
     # Convert common functions to latex
     text = text.replace('sin', '\\sin')
     text = text.replace('cos', '\\cos')
     text = text.replace('tan', '\\tan')
-    text = text.replace('asin', '\\asin')
-    text = text.replace('acos', '\\acos')
-    text = text.replace('atan', '\\atan')
+    text = text.replace('a\\sin', '\\arcsin')
+    text = text.replace('a\\cos', '\\arccos')
+    text = text.replace('a\\tan', '\\arctan')
+    text = text.replace('arc\\sin', '\\arcsin')
+    text = text.replace('arc\\cos', '\\arccos')
+    text = text.replace('arc\\tan', '\\arctan')
     text = text.replace('min', '\\min')
     text = text.replace('max', '\\max')
 
@@ -388,7 +416,7 @@ def to_latex(text):
     text = text.replace('*', ' \\cdot{}')
     text = text.replace('sqrt', '\\sqrt')
 
-    # Change any parentheses to brackets 
+    # Change any parentheses to brackets for `sqrt`, `^`, and `_`
     text = curly_brackets('sqrt', text)
     text = curly_brackets('^', text)
     text = curly_brackets('_', text)
@@ -489,7 +517,7 @@ def sscript_curly(symbol, text):
     term_list = []
     for i, char in enumerate(text):
         
-        # Find any lone symbols
+        # Find any instances of `symbol` that have not already been formatted properly
         if char == symbol and text[i:i+2] != symbol + '(' and text[i:i+2] != symbol + '{':
             
             # Initialize the term after the symbol
